<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * 
 */

function optionsframework_options() {

	// Post Navigation Links Location
	$post_nav_array = array(
		"disable" => __("Disable", "firmness"),
		"sidebar" => __("Main Sidebar", "firmness"),
		"below" => __("Below Content", "firmness"),

	);
	
	// Post Info Location
	$post_info_array = array(
		"disable" => __("Disable", "firmness"),
		"above" => __("Above Content", "firmness"),

	);
	
	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}


	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/admin/images/';
	
	// Google Fonts
	$google_fonts = array(
						"Open Sans" => "Open Sans"
					);

	// Options Enable/Disable
	$options_enable = array(
						"Enable" => __("Enable","firmness"),
						"Disable" => __("Disable","firmness"),	
					);

	// Positions
	$positions = array(
						"Left" => __("Left","firmness"),
						"Right" => __("Right","firmness"),	
					);
										
	// Excerpt or Full Blog Content
	$options_content = array(
						"Excerpt" => __("Excerpt","firmness"),
						"Full Content" => __("Full Content","firmness"),	
					);
					
	// Image Sliders
	$slider_select = array("flex" => __("Flex Slider","firmness"), "refine" => __("Refine Slider","firmness"));
	
	// Featured Posts Display
	$options_feat_posts = array("grid" => __("Grid","firmness"), "slider" => __("Image Slider","firmness"));
	
	// Animation Effecta
	$animation_effects = array("fade" => "fade", "random" => "random", "slideV" => "slideV", "slideH" => "slideH", "sliceV" => "sliceV", "sliceH" => "sliceH", "cubeV" => "cubeV", "cubeH" => "cubeH", "scale" => "scale", "kaleidoscope" => "kaleidoscope", "fan" => "fan", "blindV" => "blindV", "blindH" => "blindH");

	// Font Sizes
	$font_sizes = array(
		'10' => '10',
		'11' => '11',
		'12' => '12',
		'13' => '13',
		'14' => '14',
		'15' => '15',
		'16' => '16',
		'17' => '17',
		'18' => '18',
		'19' => '19',
		'20' => '20',
		'21' => '21',
		'22' => '22',
		'23' => '23',
		'24' => '24',
		'25' => '25',
		'26' => '26',
		'27' => '27',
		'28' => '28',
		'29' => '29',
		'30' => '30',
		'31' => '31',
		'32' => '32',
		'33' => '33',
		'34' => '34',
		'35' => '35',
		'36' => '36',
		'37' => '37',
		'38' => '38',
		'39' => '39',
		'40' => '40',
		'41' => '41',
		'42' => '42',
	);
	
	// Button Colors
	$button_colors = array("green" => __("green","firmness"),"darkgreen" => __("darkgreen","firmness"),"orange" => __("orange","firmness"), "blue" => __("blue","firmness"), "red" => __("red","firmness") ,"pink" => __("pink","firmness"), "darkgray" => __("darkgray","firmness"),"lightgray" => __("lightgray","firmness"));
	

	$options = array();

	// General Settings
	$options[] = array(
		"name" => __("General","firmness"),
		"type" => "heading");

	$options[] = array( "name" => __("Theme Color","firmness"),
		"desc" => __("Default is #ffcc00","firmness"),
		"id" => "theme_color",
		"std" => "#ffcc00",
		"type" => "color");
		
	$options[] = array( "name" 	=> __("Enable Custom Favicon","firmness"),
		"desc" => __("", "firmness"),
		"id" => "enable_favicon",
		"std" => "0",
		"type" => "checkbox");

	$options[] = array( "name" => __("Custom Favicon","firmness"),
		"desc" => __("You can upload a favicon for your theme, or specify a favicon image URL directly. Image size should be (16px x 16px)","firmness"),
		"id" => "favicon",
		"mod" => "min",
		"type" => "upload");
	
	$options[] = array( "name" 	=> __("Breadcrumbs","firmness"),
		"desc" => __("", "firmness"),
		"id" => "enable_breadcrumbs",
		"std" => "0",
		"type" => "checkbox");
		
	$options[] = array( "name" 	=> __("Animation","firmness"),
		"desc" => __("", "firmness"),
		"id" => "animation",
		"std" => "0",
		"type" => "checkbox");
		
	$options[] = array( "name" 	=> __("Responsive Design","firmness"),
		"desc" => __("", "firmness"),
		"id" => "responsive_design",
		"std" => "1",
		"type" => "checkbox");
		
	$options[] = array( "name" 	=> __("ScrollUp","firmness"),
		"desc" => __("", "firmness"),
		"id" => "enable_scrollup",
		"std" => "1",
		"type" => "checkbox");
		
	$options[] = array( "name" => __("ScrollUp Color","firmness"),
		"desc" => __("Pick the color (default is #888888)","firmness"),
		"id" => "scrollup_color",
		"std" => "#888888",
		"type" => "color");
		
	$options[] = array( "name" => __("ScrollUp Hover Color","firmness"),
		"desc" => __("Pick the color (default is #ffffff)","firmness"),
		"id" => "scrollup_hover_color",
		"std" => "#ffffff",
		"type" => "color");

	// Logo Settings
	$options[] = array(
		"name" => __("Logo", "firmness"),
		"type" => "heading");

	$options[] = array( "name" => __("Logo Width (px)","firmness"),
		"desc" => __("Default is 350","firmness"),
		"id" => "logo_width",
		"std" => "350",
		"class" => "mini",
		"type" => "text");
		
	$options[] = array( "name" => __("Logo Height (px)","firmness"),
		"desc" => __("Default is 80","firmness"),
		"id" => "logo_height",
		"std" => "80",
		"class" => "mini",
		"type" => "text");

	$options[] = array( "name" => __("Logo Top Margin (px)","firmness"),
		"desc" => __("Default is 25","firmness"),
		"id" => "logo_top_margin",
		"std" => "25",
		"class" => "mini",
		"type" => "text");
		
	$options[] = array( "name" => __("Logo Left Margin (px)","firmness"),
		"desc" => __("Default is 0","firmness"),
		"id" => "logo_left_margin",
		"std" => "0",
		"class" => "mini",
		"type" => "text");
		
	$options[] = array( "name" => __("Logo Bottom Margin (px)","firmness"),
		"desc" => __("Default is 25","firmness"),
		"id" => "logo_bottom_margin",
		"std" => "25",
		"class" => "mini",
		"type" => "text");
		
	$options[] = array( "name" => __("Logo Right Margin (px)","firmness"),
		"desc" => __("Default is 25","firmness"),
		"id" => "logo_right_margin",
		"std" => "25",
		"class" => "mini",
		"type" => "text");
		
	$options[] = array( "name" => __("Image Logo","firmness"),
		"desc" => __("You can upload a logo for your theme, or specify an image URL directly","firmness"),
		"id" => "logo",
		"mod" => "min",
		"type" => "upload");

	$options[] = array( "name" => __("Logo ALT Text","firmness"),
		"desc" => __("Specifies an alternate text for the logo","firmness"),
		"id" => "logo_alt_text",
		"std" => "Logo",
		"type" => "text");

	$options[] = array( "name" 	=> __("Logo Uppercase","firmness"),
		"desc" => __("", "firmness"),
		"id" => "logo_uppercase",
		"std" => "1",
		"type" => "checkbox");
		
	$options[] = array( "name" => __("Select Logo Font Family","firmness"),
		"desc" => __("Select logo font family","firmness"),
		"id" => "google_font_logo",
		"std" => "Open Sans",
		"type" => "select",
		"options" => $google_fonts); 

	$options[] = array( "name" => __("Logo Font Size (px)","firmness"),
		"desc" => __("Default is 50","firmness"),
		"id" => "logo_font_size",
		"std" => "50",
		"class" => "mini",
		"type" => "text");
		
	$options[] = array( "name" => __("Logo Font Weight","firmness"),
		"desc" => __("Defines from thin to thick characters (100 to 900)","firmness"),
		"id" => "logo_font_weight",
		"std" => "700",
		"class" => "mini",
		"type" => "text");
		
	$options[] = array( "name" => __("Logo Color","firmness"),
		"desc" => __("Pick logo color (default is #111111)","firmness"),
		"id" => "text_logo_color",
		"std" => "#111111",
		"type" => "color");

	$options[] = array( "name" 	=> __("Enable Tagline Underneath Logo","firmness"),
		"desc" => __("", "firmness"),
		"id" => "enable_logo_tagline",
		"std" => "1",
		"type" => "checkbox");
	
	$options[] = array( "name" => __("Tagline Font Size (px)","firmness"),
		"desc" => __("Default is 16","firmness"),
		"id" => "tagline_font_size",
		"std" => "16",
		"class" => "mini",
		"type" => "text");
		
	$options[] = array( "name" => __("Tagline Color","firmness"),
		"desc" => __("Pick tagline color (default is #111111)","firmness"),
		"id" => "tagline_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array( "name" 	=> __("Tagline Uppercase","firmness"),
		"desc" => __("", "firmness"),
		"id" => "tagline_uppercase",
		"std" => "1",
		"type" => "checkbox");

	// Navigation Menu
	$options[] = array(
		"name" => __("Navigation", "firmness"),
		"type" => "heading");

	$options[] = array( "name" => __("Select Main Navigation Menu Font Family","firmness"),
		"desc" => __("Select a font family for the main navigation menu","firmness"),
		"id" => "google_font_menu",
		"std" => "Open Sans",
		"type" => "select",
		"options" => $google_fonts); 
		
	$options[] = array( "name" 	=> __("Main Navigation Menu Font Size (px)","firmness"),
		"desc" => __("Select the font size, default value: 14","firmness"),
		"id" => "nav_font_size",
		"std" => "14",
		"class" => "mini",
		"type" => "text");
		
	$options[] = array( "name" 	=> __("Uppercase Menu","firmness"),
		"desc" => __("", "firmness"),
		"id" => "menu_uppercase",
		"std" => "1",
		"type" => "checkbox");

	$options[] = array( "name" => __("Main Navigation Menu Font Color","firmness"),
		"desc" => __("Pick a main navigation menu font color (default is #111111)","firmness"),
		"id" => "nav_font_color",
		"std" => "#111111",
		"type" => "color");
					
	$options[] = array( "name" => __("Main Navigation Menu Border Color","firmness"),
		"desc" => __("Pick border color for the main navigation menu (default is #111111)","firmness"),
		"id" => "nav_border_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array( "name" => __("Main Navigation Background Color","firmness"),
		"desc" => __("Pick background color for the main navigation menu (default is #ffcc00)","firmness"),
		"id" => "nav_bg_color",
		"std" => "#ffcc00",
		"type" => "color");
		
	$options[] = array( "name" => __("Main Navigation Menu SubMenu Background Color","firmness"),
		"desc" => __("Pick a background color for the navigation menu submenu (default #ffcc00)","firmness"),
		"id" => "nav_bg_sub_color",
		"std" => "#ffcc00",
		"type" => "color");

	$options[] = array( "name" => __("Main Navigation Menu Hover Font Color","firmness"),
		"desc" => __("Pick a main navigation menu hover font color (default is #ffffff)","firmness"),
		"id" => "nav_hover_font_color",
		"std" => "#ffffff",
		"type" => "color");

	$options[] = array( "name" => __("Main Navigation Menu Background Hover Color","firmness"),
		"desc" => __("Pick a background hover color for the main navigation menu (default #ffcc00)","firmness"),
		"id" => "nav_bg_hover_color",
		"std" => "#ffcc00",
		"type" => "color");
		
	$options[] = array( "name" => __("Main Navigation Selected Menu Color","firmness"),
		"desc" => __("Pick a selected menu item color (default #ffffff)","firmness"),
		"id" => "nav_cur_item_color",
		"std" => "#ffffff",
		"type" => "color");
						
	// Typography Settings
	$options[] = array(
		"name" => __("Typography", "firmness"),
		"type" => "heading");

	$options[] = array( "name" => __("Select Body Font Family","firmness"),
		"desc" => __("Select a font family for body text","firmness"),
		"id" => "google_font_body",
		"std" => "Open Sans",
		"type" => "select",
		"options" => $google_fonts); 

	$options[] = array( "name" => __("Body Font Size (px)","firmness"),
		"desc" => __("Default is 15","firmness"),
		"id" => "body_font_size",
		"std" => "15",
		"type" => "select",
		"options" => $font_sizes);

	$options[] = array( "name" =>  __("Body Font Color","firmness"),
		"desc" => __("Pick body font color. ( Default: #777777 )","firmness"),
		"id" => "body_font_color",
		"std" => "#777777",
		"type" => "color");						

	// Header Settings
	$options[] = array(
		"name" => __("Header", "firmness"),
		"type" => "heading");

	$options[] = array( "name" => __("Header Address Section","firmness"),
		"desc" => __("Enable or Disable header address section","firmness"),
		"id" => "header_address_enable",
		"std" => "1",
		"type" => "checkbox");
		
	$options[] = array( "name" => __("Address", "firmness"),
		"desc" => __("", "firmness"),
		"id" => "header_address",
		"std" => "1234 Street Name, City Name, United States",
		"type" => "text");
		
	$options[] = array( "name" => __("Phone Number", "firmness"),
		"desc" => __("", "firmness"),
		"id" => "header_phone",
		"std" => "(123) 456-7890",
		"type" => "text");
		
	$options[] = array( "name" => __("Email", "firmness"),
		"desc" => __("", "firmness"),
		"id" => "header_email",
		"std" => "info@yourdomain.com",
		"type" => "text");
		
	$options[] = array( "name" =>  __("Header Address Section Color","firmness"),
		"desc" => __("Pick address section color. ( Default: #111111 )","firmness"),
		"id" => "address_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array( "name" => __("Header Social Links","firmness"),
		"desc" => __("Enable or Disable header social links","firmness"),
		"id" => "header_social_enable",
		"std" => "1",
		"type" => "checkbox");
		
	$options[] = array( "name" =>  __("Header Social Links Color","firmness"),
		"desc" => __("Pick social links icons color. ( Default: #111111 )","firmness"),
		"id" => "header_social_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Header Social Links Box Color","firmness"),
		"desc" => __("Pick social links icons box color. ( Default: #ffcc00 )","firmness"),
		"id" => "header_social_box_color",
		"std" => "#ffcc00",
		"type" => "color");
	
	if(class_exists('Woocommerce')) {
		$options[] = array( "name" => __("Shopping Cart","firmness"),
			"desc" => __("Enable or Disable shopping cart.","firmness"),
			"id" => "shopping_cart_enable",
			"std" => "1",
			"type" => "checkbox");
			
		$options[] = array( "name" =>  __("Shopping Cart Section Color","firmness"),
			"desc" => __("Pick shopping cart section color. ( Default: #111111 )","firmness"),
			"id" => "shopping_color",
			"std" => "#111111",
			"type" => "color");
	}
	
	$options[] = array( "name" => __("Header Search Form","firmness"),
		"desc" => __("Enable or Disable header search form","firmness"),
		"id" => "header_search_enable",
		"std" => "0",
		"type" => "checkbox");
										
	// Home Page Settings
	$options[] = array(
		"name" => __("Home Page", "firmness"),
		"type" => "heading");
		
	$options[] = array( "name" => __("Enable Image Slider on Home Page","firmness"),
		"desc" => __("", "firmness"),
		"id" => "image_slider_on",
		"std" => "1",
		"type" => "checkbox");	
		
	$options[] = array( "name" => __("Display Features Section on Home Page","firmness"),
		"desc" => __("", "firmness"),
		"id" => "features_section_on",
		"std" => "1",
		"type" => "checkbox");
		
	$options[] = array( "name" => __("Display Services Section on Home Page","firmness"),
		"desc" => __("", "firmness"),
		"id" => "services_section_on",
		"std" => "1",
		"type" => "checkbox");
		
	$options[] = array( "name" => __("Display About Section on Home Page","firmness"),
		"desc" => __("", "firmness"),
		"id" => "about_section_on",
		"std" => "1",
		"type" => "checkbox");	

	$options[] = array( "name"	=> __("About Section Header Text","firmness"),
		"desc" => __("", "firmness"),
		"id" => "about_section_header",
		"std" => "About Us",
		"type" => "text");
		
	$options[] = array( "name"	=> __("About Section Text","firmness"),
		"desc" => __("", "firmness"),
		"id" => "about_section_text",
		"std" => "Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.",
		"type" => "textarea");	
		
	$options[] = array( "name" =>  __("About Section Text Color","firmness"),
		"desc" => __("Pick text color. ( Default: #111111 )","firmness"),
		"id" => "about_text_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array( "name" =>  __("About Section Background Color","firmness"),
		"desc" => __("Pick background color. ( Default: #ffffff )","firmness"),
		"id" => "about_bg_color",
		"std" => "#ffffff",
		"type" => "color");	

	$options[] = array( "name" => __("Display Content Boxes Section on Home Page","firmness"),
		"desc" => __("", "firmness"),
		"id" => "content_boxes_section_on",
		"std" => "0",
		"type" => "checkbox");
		
	$options[] = array( "name" => __("Display Blog Posts on Home Page","firmness"),
		"desc" => __("", "firmness"),
		"id" => "blog_posts_on",
		"std" => "1",
		"type" => "checkbox");
											
	// Image Slider Settings
	$options[] = array(
		"name" => __("Image Slider", "firmness"),
		"type" => "heading");
		
	$options[] = array( "name" => __("Default Image Slider:", "firmness"),
		"desc" => __("", "firmness"),
		"id" => "default_slider",
		"std" => "refine",
		"type" => "select",
		"options" => $slider_select);
		
	$options[] = array( "name" => __("Select Image Slider Category","firmness"),
		"desc" => __("", "firmness"),
		"id" => "image_slider_cat",
		"std" => "",
		"type" => "select",
		"options" => $options_categories);
		
	$options[] = array( "name" => __("Slider Animation Effect:", "firmness"),
		"desc" => __("", "firmness"),
		"id" => "slider_animation",
		"std" => "fade",
		"type" => "select",
		"options" => $animation_effects);
		
	$options[] = array( "name" => __("Slideshow Speed", "firmness"),
		"desc" => __("Select the slideshow speed, 1000 = 1 second, default value: 5000","firmness"),
		"id" => "slideshow_speed",
		"std" => "5000",
		"class" => "mini",
		"type" => "text");
					
	$options[] = array( "name" => __("Animation Speed", "firmness"),
		"desc" => __("Select the animation speed, 1000 = 1 second, default value: 800","firmness"),
		"id" => "animation_speed",
		"std" => "800",
		"class" => "mini",
		"type" => "text" );

	$options[] = array( "name" => __("Number of Slides to Display", "firmness"),
		"desc" => __("", "firmness"),
		"id" => "slider_num",
		"std" => "3",
		"class" => "mini",
		"type" => "text" );

	$options[] = array("name" => __("Slider Captions", "firmness"),
		"desc" => __("Enable/Disable captions on a slide","firmness"),
		"id" => "captions",
		"std" => "0",
		"type" => "checkbox");
		
	$options[] = array( "name" => __("Captions Background Color","firmness"),
		"desc" => __("Pick a background color (default is #ffcc00)","firmness"),
		"id" => "captions_bg_color",
		"std" => "#ffcc00",
		"type" => "color");
		
	$options[] = array( "name" => __("Captions Font Color","firmness"),
		"desc" => __("Pick the font color (default is #111111)","firmness"),
		"id" => "captions_font_color",
		"std" => "#111111",
		"type" => "color");
		
	// Footer Options
	$options[] = array(
		"name" => __("Footer", "firmness"),
		"type" => "heading");

	$options[] = array( "name" => __("Footer Background Color","firmness"),
		"desc" => __("Pick a background color (default is #252525)","firmness"),
		"id" => "footer_bg_color",
		"std" => "#252525",
		"type" => "color");

	$options[] = array( "name" => __("Copyright Section Background Color","firmness"),
		"desc" => __("Pick a background color (default is #111111)","firmness"),
		"id" => "copyright_bg_color",
		"std" => "#111111",
		"type" => "color");

	$options[] = array( "name" => __("Footer Widget Title Color","firmness"),
		"desc" => __("Pick a widget title color (default is #ffffff)","firmness"),
		"id" => "footer_widget_title_color",
		"std" => "#ffffff",
		"type" => "color");
		
	$options[] = array( "name" => __("Footer Widget Title Border Color","firmness"),
		"desc" => __("Pick a widget title border color (default is #444444)","firmness"),
		"id" => "footer_widget_title_border_color",
		"std" => "#444444",
		"type" => "color");
		
	$options[] = array( "name" => __("Footer Widget Text Color","firmness"),
		"desc" => __("Pick a widget text color (default is #ffffff)","firmness"),
		"id" => "footer_widget_text_color",
		"std" => "#ffffff",
		"type" => "color");
		
	$options[] = array( "name" => __("Footer Widget Text Border Color","firmness"),
		"desc" => __("Pick a widget text border color (default is #444444)","firmness"),
		"id" => "footer_widget_text_border_color",
		"std" => "#444444",
		"type" => "color");

	$options[] = array( "name" => __("Footer Widgets","firmness"),
		"desc" 		=> __("Turn On / Off footer widgets","firmness"),
		"id" 		=> "footer_widgets",
		"std" 		=> "1",
		"type" 		=> "checkbox");
		
	$options[] = array( "name" => __("Copyright Text","firmness"),
         "desc" => __("", "firmness"),
         "id" => "footer_copyright_text",
         "std" => 'Copyright '.date('Y').' '.get_bloginfo('site_title'),
         "type" => "textarea");

	// Layout Options
	$options[] = array(
		"name" => __("Layout", "firmness"),
		"type" => "heading");
		
	$options[] = array(
		'name' => __("Select the Layout","firmness"),
		"desc" => __("", "firmness"),
		'id' => "layout_settings",
		'std' => "col2-l",
		'type' => "images",
		'options' => array(
			'col1' => $imagepath . 'col-1c.png',
			'col2-l' => $imagepath . 'col-2cl.png',
			'col2-r' => $imagepath . 'col-2cr.png')
	);

	// Blog Options
	$options[] = array(
		"name" => __("Blog Options", "firmness"),
		"type" => "heading");

	$options[] = array( "name" 	=> __("Excerpt or Full Blog Content","firmness"),
		"desc" => __("Show excerpt or full blog content on archive / blog pages","firmness"),
		"id" => "blog_content",
		"std" => "Excerpt",
		"options" => $options_content,
		"type" => "select");
		
	$options[] = array( "name"	=> __("Blog Excerpt Length","firmness"),
		"desc" => __("Default: 50","firmness"),
		"id" => "blog_excerpt",
		"std" => "50",
		"class" => "mini",
		"type" => "text");
		
	$options[] = array( "name" 	=> __("Use Simple Pagination","firmness"),
		"desc" => __("Enable/Disable simple pagination","firmness"),
		"id" => "simple_paginaton",
		"std" => "0",
		"type" => "checkbox");
		
	$options[] = array(
		"name" => __("Post Navigation Links", "firmness"),
		"desc" => __("Shows links to the next and previous article","firmness"),
		"id" => "post_navigation",
		"std" => "sidebar",
		"type" => "radio",
		"options" => $post_nav_array);
		
	$options[] = array(
		"name" => __("Post Info", "firmness"),
		"desc" => __("Shows post info","firmness"),
		"id" => "post_info",
		"std" => "above",
		"type" => "radio",
		"options" => $post_info_array);
		
	$options[] = array( "name" 	=> __("Display Featured Image Inside the Post","firmness"),
		"desc" => __("Enable/Disable featured image inside the post","firmness"),
		"id" => "featured_img_post",
		"std" => "1",
		"type" => "checkbox");

	// Features Settings
	$options[] = array(
		"name" => __("Features", "firmness"),
		"type" => "heading");		

	$options[] = array( "name"	=> __("Section Title","firmness"),
		"desc" => __("", "firmness"),
		"id" => "features_section_title",
		"std" => "Clean Design & Great Functionality",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Section Description","firmness"),
		"desc" => __("", "firmness"),
		"id" => "features_section_desc",
		"std" => "Lorem ipsum dolor sit amet pellentesque",
		"type" => "text");
				
	$options[] = array( "name"	=> __("Feature #1 Title","firmness"),
		"desc" => __("", "firmness"),
		"id" => "feature_one",
		"std" => "Responsive Design",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #1 Description","firmness"),
		"desc" => __("", "firmness"),
		"id" => "feature_one_desc",
		"std" => "Lorem ipsum dolor sit",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #1 Icon","firmness"),
		"desc" => sprintf( __( 'Enter Font Awesome icon name. For icon name refer to: <a href="%1$s" target="_blank">Font Awesome Website</a>', 'firmness' ), 'http://fortawesome.github.io/Font-Awesome/icons/' ),
		"id" => "feature_one_icon",
		"std" => "fa-tablet",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #1 URL","firmness"),
		"desc" => __("", "firmness"),
		"id" => "feature_one_url",
		"std" => "",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #2 Title","firmness"),
		"desc" => __("", "firmness"),
		"id" => "feature_two",
		"std" => "Unlimited Colors",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #2 Description","firmness"),
		"desc" => __("", "firmness"),
		"id" => "feature_two_desc",
		"std" => "Lorem ipsum dolor sit",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #2 Icon","firmness"),
		"desc" => sprintf( __( 'Enter Font Awesome icon name. For icon name refer to: <a href="%1$s" target="_blank">Font Awesome Website</a>', 'firmness' ), 'http://fortawesome.github.io/Font-Awesome/icons/' ),
		"id" => "feature_two_icon",
		"std" => "fa-tint",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #2 URL","firmness"),
		"desc" => __("", "firmness"),
		"id" => "feature_two_url",
		"std" => "",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #3 Title","firmness"),
		"desc" => __("", "firmness"),
		"id" => "feature_three",
		"std" => "Clean Code",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #3 Description","firmness"),
		"desc" => __("", "firmness"),
		"id" => "feature_three_desc",
		"std" => "Lorem ipsum dolor sit",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #3 Icon","firmness"),
		"desc" => sprintf( __( 'Enter Font Awesome icon name. For icon name refer to: <a href="%1$s" target="_blank">Font Awesome Website</a>', 'firmness' ), 'http://fortawesome.github.io/Font-Awesome/icons/' ),
		"id" => "feature_three_icon",
		"std" => "fa-html5",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #3 URL","firmness"),
		"desc" => __("", "firmness"),
		"id" => "feature_three_url",
		"std" => "",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #4 Title","firmness"),
		"desc" => __("", "firmness"),
		"id" => "feature_four",
		"std" => "eCommerce Ready",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #4 Description","firmness"),
		"desc" => __("", "firmness"),
		"id" => "feature_four_desc",
		"std" => "Lorem ipsum dolor sit",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #4 Icon","firmness"),
		"desc" => sprintf( __( 'Enter Font Awesome icon name. For icon name refer to: <a href="%1$s" target="_blank">Font Awesome Website</a>', 'firmness' ), 'http://fortawesome.github.io/Font-Awesome/icons/' ),
		"id" => "feature_four_icon",
		"std" => "fa-shopping-cart",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Feature #4 URL","firmness"),
		"desc" => __("", "firmness"),
		"id" => "feature_four_url",
		"std" => "",
		"type" => "text");

	// Our Services Settings
	$options[] = array(
		"name" => __("Our Sevices", "firmness"),
		"type" => "heading");
		
	$options[] = array( "name"	=> __("Section Title","firmness"),
		"desc" => __("", "firmness"),
		"id" => "services_section_title",
		"std" => "Our Services",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Section Description","firmness"),
		"desc" => __("", "firmness"),
		"id" => "services_section_desc",
		"std" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec ut ipsum mauris. Fusce condimentum mollis eros vitae facilisis. Praesent gravida dignissim felis, id sagittis mauris rutrum non. Nullam pretium id sem ut hendrerit.",
		"type" => "textarea");
		
	$options[] = array( "name" => __("Section Image","firmness"),
		"desc" => __("","firmness"),
		"id" => "services_image",
		"std" => get_template_directory_uri() . "/images/assets/tablet-313002_640.jpg",
		"mod" => "min",
		"type" => "upload");
				
	$options[] = array( "name"	=> __("Service #1 Title","firmness"),
		"desc" => __("", "firmness"),
		"id" => "service_one",
		"std" => "Easy to Use",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Service #1 Description","firmness"),
		"desc" => __("", "firmness"),
		"id" => "service_one_desc",
		"std" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec ut ipsum mauris. Fusce condimentum mollis eros vitae facilisis.",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Service #1 Icon","firmness"),
		"desc" => sprintf( __( 'Enter Font Awesome icon name. For icon name refer to: <a href="%1$s" target="_blank">Font Awesome Website</a>', 'firmness' ), 'http://fortawesome.github.io/Font-Awesome/icons/' ),
		"id" => "service_one_icon",
		"std" => "fa-coffee",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Service #2 Title","firmness"),
		"desc" => __("", "firmness"),
		"id" => "service_two",
		"std" => "Works Everywhere",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Service #2 Description","firmness"),
		"desc" => __("", "firmness"),
		"id" => "service_two_desc",
		"std" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec ut ipsum mauris. Fusce condimentum mollis eros vitae facilisis.",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Service #2 Icon","firmness"),
		"desc" => sprintf( __( 'Enter Font Awesome icon name. For icon name refer to: <a href="%1$s" target="_blank">Font Awesome Website</a>', 'firmness' ), 'http://fortawesome.github.io/Font-Awesome/icons/' ),
		"id" => "service_two_icon",
		"std" => "fa-paper-plane",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Service #3 Title","firmness"),
		"desc" => __("", "firmness"),
		"id" => "service_three",
		"std" => "Great Performance",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Service #3 Description","firmness"),
		"desc" => __("", "firmness"),
		"id" => "service_three_desc",
		"std" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec ut ipsum mauris. Fusce condimentum mollis eros vitae facilisis.",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Service #3 Icon","firmness"),
		"desc" => sprintf( __( 'Enter Font Awesome icon name. For icon name refer to: <a href="%1$s" target="_blank">Font Awesome Website</a>', 'firmness' ), 'http://fortawesome.github.io/Font-Awesome/icons/' ),
		"id" => "service_three_icon",
		"std" => "fa-tachometer",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Service #4 Title","firmness"),
		"desc" => __("", "firmness"),
		"id" => "service_four",
		"std" => "Clean Code",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Service #4 Description","firmness"),
		"desc" => __("", "firmness"),
		"id" => "service_four_desc",
		"std" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec ut ipsum mauris. Fusce condimentum mollis eros vitae facilisis.",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Service #4 Icon","firmness"),
		"desc" => sprintf( __( 'Enter Font Awesome icon name. For icon name refer to: <a href="%1$s" target="_blank">Font Awesome Website</a>', 'firmness' ), 'http://fortawesome.github.io/Font-Awesome/icons/' ),
		"id" => "service_four_icon",
		"std" => "fa-code",
		"type" => "text");	
		
	// Content Boxes Settings
	$options[] = array(
		"name" => __("Content Boxes", "firmness"),
		"type" => "heading");
		
	$options[] = array( "name" => __("First Column Header", "firmness"),
		"desc" => __("Enter text to display in the header of the first column","firmness"),
		"id" => "first_column_header",
		"std" => "Responsive Design",
		"type" => "text");
		
	$options[] = array( "name" => __("First Column Text", "firmness"),
		"desc" => __("Enter text to display in the body of the first column","firmness"),
		"id" => "first_column_text",
		"std" => "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.",
		"type" => "textarea");
		
	$options[] = array( "name" => __("First Column Image", "firmness"),
		"desc" => sprintf( __( 'Enter Font Awesome icon name. For icon name refer to: <a href="%1$s" target="_blank">Font Awesome Website</a>', 'firmness' ), 'http://fortawesome.github.io/Font-Awesome/icons/' ),
		"id" => "first_column_image",
		"std" => "fa-tablet",
		"type" => "text");
		
	$options[] = array( "name"	=> __("First Column URL","firmness"),
		"desc" => __("", "firmness"),
		"id" => "first_column_url",
		"std" => "",
		"type" => "text");
		
	$options[] = array( "name" => __("Second Column Header", "firmness"),
		"desc" => __("Enter text to display in the header of the second column","firmness"),
		"id" => "second_column_header",
		"std" => "High Quality",
		"type" => "text");
		
	$options[] = array( "name" => __("Second Column Text", "firmness"),
		"desc" => __("Enter text to display in the body of the second column","firmness"),
		"id" => "second_column_text",
		"std" => "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.",
		"type" => "textarea");
		
	$options[] = array( "name" => __("Second Column Image", "firmness"),
		"desc" => sprintf( __( 'Enter Font Awesome icon name. For icon name refer to: <a href="%1$s" target="_blank">Font Awesome Website</a>', 'firmness' ), 'http://fortawesome.github.io/Font-Awesome/icons/' ),
		"id" => "second_column_image",
		"std" => "fa-umbrella",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Second Column URL","firmness"),
		"desc" => __("", "firmness"),
		"id" => "second_column_url",
		"std" => "",
		"type" => "text");
		
	$options[] = array( "name" => __("Third Column Header", "firmness"),
		"desc" => __("Enter text to display in the header of the third column","firmness"),
		"id" => "third_column_header",
		"std" => "Tons of Features",
		"type" => "text");
		
	$options[] = array( "name" => __("Third Column Text", "firmness"),
		"desc" => __("Enter text to display in the body of the third column","firmness"),
		"id" => "third_column_text",
		"std" => "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.",
		"type" => "textarea");
		
	$options[] = array( "name" => __("Third Column Image", "firmness"),
		"desc" => sprintf( __( 'Enter Font Awesome icon name. For icon name refer to: <a href="%1$s" target="_blank">Font Awesome Website</a>', 'firmness' ), 'http://fortawesome.github.io/Font-Awesome/icons/' ),
		"id" => "third_column_image",
		"std" => "fa-cog",
		"type" => "text");
		
	$options[] = array( "name"	=> __("Third Column URL","firmness"),
		"desc" => __("", "firmness"),
		"id" => "third_column_url",
		"std" => "",
		"type" => "text");
		
	$options[] = array( "name" =>  __("Section Text Color","firmness"),
		"desc" => __("Pick text color. ( Default: #777777 )","firmness"),
		"id" => "cont_text_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Section Background Color","firmness"),
		"desc" => __("Pick background color. ( Default: #ffffff )","firmness"),
		"id" => "cont_bg_color",
		"std" => "#ffffff",
		"type" => "color");
		
	// Widgets Options
	$options[] = array(
		"name" => __("Widgets", "firmness"),
		"type" => "heading");
				
	$options[] = array(
		"name" => __("Archives Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Archives Widget Font Color","firmness"),
		"desc" => __("Pick font color. ( Default: #777777 )","firmness"),
		"id" => "archives_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Archives Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "archives_widget_title_color",
		"std" => "#111111",
		"type" => "color");	
		
	$options[] = array(
		"name" => __("Categories Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Categories Widget Font Color","firmness"),
		"desc" => __("Pick font color. ( Default: #777777 )","firmness"),
		"id" => "categories_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Categories Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "categories_widget_title_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array(
		"name" => __("Calendar Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Calendar Widget Font Color","firmness"),
		"desc" => __("Pick font color. ( Default: #777777 )","firmness"),
		"id" => "calendar_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Calendar Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "calendar_widget_title_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array(
		"name" => __("Custom Menu Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Custom Menu Widget Font Color","firmness"),
		"desc" => __("Pick font color. ( Default: #777777 )","firmness"),
		"id" => "custom_menu_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Custom Menu Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "custom_menu_widget_title_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array(
		"name" => __("Links Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Links Widget Font Color","firmness"),
		"desc" => "Pick font color. ( Default: #777777 )",
		"id" => "links_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Links Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "links_widget_title_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array(
		"name" => __("Meta Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Meta Widget Font Color","firmness"),
		"desc" => __("Pick font color. ( Default: #777777 )","firmness"),
		"id" => "meta_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Meta Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "meta_widget_title_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array(
		"name" => __("Pages Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Pages Widget Font Color","firmness"),
		"desc" => __("Pick font color. ( Default: #777777 )","firmness"),
		"id" => "pages_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Pages Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "pages_widget_title_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array(
		"name" => __("Recent Comments Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Recent Comments Widget Font Color","firmness"),
		"desc" => __("Pick font color. ( Default: #777777 )","firmness"),
		"id" => "recent_comments_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Recent Comments Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "recent_comments_widget_title_color",
		"std" => "#111111",
		"type" => "color");

	$options[] = array(
		"name" => __("Recent Posts Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Recent Posts Widget Font Color","firmness"),
		"desc" => __("Pick font color. ( Default: #777777 )","firmness"),
		"id" => "recent_posts_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Recent Posts Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "recent_posts_widget_title_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array(
		"name" => __("RSS Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("RSS Widget Font Color","firmness"),
		"desc" =>__( "Pick font color. ( Default: #777777 )","firmness"),
		"id" => "rss_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("RSS Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "rss_widget_title_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array(
		"name" => __("Search Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Search Widget Font Color","firmness"),
		"desc" => __("Pick font color. ( Default: #777777 )","firmness"),
		"id" => "search_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Search Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "search_widget_title_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array(
		"name" => __("Tag Cloud Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Tag Cloud Widget Font Color","firmness"),
		"desc" => __("Pick font color. ( Default: #ffffff )","firmness"),
		"id" => "tag_cloud_widget_font_color",
		"std" => "#ffffff",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Tag Cloud Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "tag_cloud_widget_title_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array(
		"name" => __("Text Widget Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Text Widget Font Color","firmness"),
		"desc" => __("Pick font color. ( Default: #777777 )","firmness"),
		"id" => "text_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Text Widget Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "text_widget_title_color",
		"std" => "#111111",
		"type" => "color");
		
	$options[] = array(
		"name" => __("Other Widgets Settings:", "firmness"),
		"desc" => __("", "firmness"),
		"type" => "info");
		
	$options[] = array( "name" =>  __("Other Widgets Font Color","firmness"),
		"desc" => __("Pick font color. ( Default: #777777 )","firmness"),
		"id" => "other_widget_font_color",
		"std" => "#777777",
		"type" => "color");
		
	$options[] = array( "name" =>  __("Other Widgets Title Color","firmness"),
		"desc" => __("Pick title color. ( Default: #111111 )","firmness"),
		"id" => "other_widget_title_color",
		"std" => "#111111",
		"type" => "color");
		
	// Social Links		
	$options[] = array(
		'name' => __('Social Links', 'firmness'),
		'type' => 'heading');

	$options[] = array( "name" => __("Facebook","firmness"),
		"desc" => __("Enter your profile URL. To remove it, just leave it blank","firmness"),
		"id" => "facebook_link",
		"std" => "#",
		"type" => "text"); 

	$options[] = array( "name" => __("Flickr","firmness"),
		"desc" => __("Enter your profile URL. To remove it, just leave it blank","firmness"),
		"id" => "flickr_link",
		"std" => "#",
		"type" => "text");

	$options[] = array( "name" => __("RSS","firmness"),
		"desc" => __("Enter your profile URL. To remove it, just leave it blank","firmness"),
		"id" => "rss_link",
		"std" => "#",
		"type" => "text"); 

	$options[] = array( "name" => __("Twitter","firmness"),
		"desc" => __("Enter your profile URL. To remove it, just leave it blank","firmness"),
		"id" => "twitter_link",
		"std" => "#",
		"type" => "text");

	$options[] = array( "name" => __("Youtube","firmness"),
		"desc" => __("Enter your profile URL. To remove it, just leave it blank","firmness"),
		"id" => "youtube_link",
		"std" => "#",
		"type" => "text");

	$options[] = array( "name" => __("Pinterest","firmness"),
		"desc" => __("Enter your profile URL. To remove it, just leave it blank","firmness"),
		"id" => "pinterest_link",
		"std" => "#",
		"type" => "text");

	$options[] = array( "name" => __("Tumblr","firmness"),
		"desc" => __("Enter your profile URL. To remove it, just leave it blank","firmness"),
		"id" => "tumblr_link",
		"std" => "#",
		"type" => "text");

	$options[] = array( "name" => __("Google Plus","firmness"),
		"desc" => __("Enter your profile URL. To remove it, just leave it blank","firmness"),
		"id" => "google_link",
		"std" => "#",
		"type" => "text");

	$options[] = array( "name" => __("Dribbble","firmness"),
		"desc" => __("Enter your profile URL. To remove it, just leave it blank","firmness"),
		"id" => "dribbble_link",
		"std" => "#",
		"type" => "text");

	$options[] = array( "name" => __("LinkedIn","firmness"),
		"desc" => __("Enter your profile URL. To remove it, just leave it blank","firmness"),
		"id" => "linkedin_link",
		"std" => "#",
		"type" => "text");
		
	$options[] = array( "name" => __("Instagram","firmness"),
		"desc" => __("Enter your profile URL. To remove it, just leave it blank","firmness"),
		"id" => "instagram_link",
		"std" => "#",
		"type" => "text");
			
	return $options;
}